==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation> أظهر النافذة</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>تغيير لملء الشاشة</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>مساعده</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>لايمكن ايجاد اداراه الملفات </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation> الرجاء تنصيب اداره الملفات</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>لم يبدأ التسجيل، لاتوجد مساحة حرة كافية على القرص.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>تم الوصول إلى حد المساحة الفارغة على القرص.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation> مساحه التخزين المتاحه: </translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>ميغابايت</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>توقّف التسجيل، لاتوجد مساحة حرة كافية على القرص.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>نافذة</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>لايمكن ايجاد اداراه الملفات </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation> الرجاء تنصيب اداره الملفات</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>الملف المصدري</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>صفحة البرنامج</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>الترجمات</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>تبرع</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>واصل</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>اُخرج</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>واصل</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>اُخرج</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>الحوار</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>تغيير الوجه الأفقي</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>تغيير الوجه الرأسي</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>عكس</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>ابيض واسود</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>إزالة إطار النافذة</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>اعدادات الكاميرا</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>أعاده للوضع </translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>عدّ تنازلي</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>حجم ملف الفيديو</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>مساحه التخزين المتاحه:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>معلومه</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>مده التسجيل</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>المشاهد</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>ترميز الفيديو</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>الصيغة</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>ترميز الصوت</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>جوده</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>لا تسجل مؤشر الفأرة</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>ساعه</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>دقيقه</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>بدأ الموقت</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>اوقف التسجيل بعد</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>ساعات</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>دقائق</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>ثواني</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>مسار الفيديو</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation> مساحه التخزين المتاحه: </translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>أظهِر البرنامج في مساحة التبليغ</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>الانتظار الثاني قبل التسجيل</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>ابحث عن التحديثات</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعده</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>قيديو</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>المتاح</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>غير متاح</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>واصل</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>دليل</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>عكس</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>ارسل التقرير</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>شغل اخر تسجيل</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>افتح الدليل</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation> تصغير البرنامج عند بدأ التسجيل </translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation> البدء  بوضع التصغير </translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>تغيير الوجه الأفقي</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>تغيير الوجه الرأسي</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>ابيض واسود</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>إزالة إطار النافذة</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>تبرع</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>إعادة ضبط جميع الإعدادات في التشغيل القادم</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>حقوق الطبع والنشر والترخيص من الصور</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>ميغابايت</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>القاء الشاشة</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>المشغّل</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>سجل</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>حقوق الطبع والنشر والترخيص من الصور</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>افتح الملف</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>الإطار السابق</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>الإطار التالي</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>صامت</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>حرك قائمه الخيارات</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.3.0.orig.tar.gz: vokoscreenNG-3.3.0/src/language/ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation> أظهر النافذة</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>تغيير لملء الشاشة</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>كان الإعداد ناجحًا.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>أغلق هذه النافذة وابدأ تشغيل vokoscreenNG مرة أخرى.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>استمتع مع vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>مساعده</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>لايمكن ايجاد اداراه الملفات </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>الرجاء تنصيب اداره الملفات</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>لم يبدأ التسجيل، لاتوجد مساحة حرة كافية على القرص.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>تم الوصول إلى الحد الأقصى لمساحة القرص الحرة.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation> مساحه التخزين المتاحه: </translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>ميغابايت</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>توقّف التسجيل، لاتوجد مساحة حرة كافية على القرص.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>نافذة</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>لايمكن ايجاد اداراه الملفات </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>الرجاء تنصيب اداره الملفات</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>الملف المصدري</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>صفحة البرنامج</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>الترجمات</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>تبرع</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>اِختر جهازاً أو أكثر</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>واصل</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>اُخرج</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>واصل</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>اُخرج</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>الحوار</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>تغيير الوجه الأفقي</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>تغيير الوجه الرأسي</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>عكس</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>ابيض واسود</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>إزالة إطار النافذة</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>اعدادات الكاميرا</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>منطقة</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>أعاده للوضع </translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>المكبّرة</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>عدّ تنازلي</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>حجم ملف الفيديو</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>مساحه التخزين المتاحه:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>معلومه</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>مده التسجيل</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>المشاهد</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>ترميز الفيديو</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>الصيغة</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>ترميز الصوت</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>جوده</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>لا تسجل مؤشر الفأرة</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>ساعه</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>دقيقه</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>بدأ الموقت</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>اوقف التسجيل بعد</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>ساعات</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>دقائق</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>ثواني</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>مسار الفيديو</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation> مساحه التخزين المتاحه: </translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>أظهِر البرنامج في مساحة التبليغ</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>الانتظار الثاني قبل التسجيل</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>ابحث عن التحديثات</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعده</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>قيديو</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>المتاح</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>غير متاح</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>اِبدأ</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>واصل</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>دليل</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>عكس</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>رمادي</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>ارسل التقرير</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>شغل اخر تسجيل</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>افتح الدليل</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation> تصغير البرنامج عند بدأ التسجيل </translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation> البدء بوضع التصغير </translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>تغيير الوجه الأفقي</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>تغيير الوجه الرأسي</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>ابيض واسود</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>إزالة إطار النافذة</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>تبرع</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>إعادة ضبط جميع الإعدادات في التشغيل القادم</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>حقوق الطبع والنشر والترخيص من الصور</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>ميغابايت</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>القاء الشاشة</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>المشغّل</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>سجل</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>تلقائيا</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>إنشاء صور لعلامات التبويب</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>معلومات الترخيص</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>إيقاف</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>اختصارات لوحة المفاتيح العامة</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>مفاتيح الاختصار المعينة.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>لم يتم تعيين اختصار لوحة المفاتيح أو تم التعيين أكثر من مرة.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>إذا ظهر أنه تم تعيينه ولكنه لا يعمل ، فهذا يعني أنه قيد الاستخدام من قبل برنامج آخر.</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>حقوق الطبع والنشر والترخيص من الصور</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>شغّل</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>ألبِث</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>افتح الملف</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>شاشة كاملة</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>الإطار السابق</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>الإطار التالي</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>صامت</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>حرك قائمه الخيارات</translation>
    </message>
</context>
</TS>
